==> pulin-vue3-common-0.0.20.tgz: package/es/components/MyUpload/index.js <==
import { resolveComponent as _resolveComponent, createVNode as _createVNode, createTextVNode as _createTextVNode, Fragment as _Fragment } from "vue";

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

import { defineComponent, ref, watchEffect } from 'vue';
import { useVModel } from '@vueuse/core';
export var MyUpload = defineComponent({
  props: {
    value: Array,
    action: String,
    data: Object,
    size: {
      type: Number,
      "default": 5
    }
  },
  setup: function setup(props, _ref) {
    var emit = _ref.emit;
    var uploaddata = ref({});
    var previewVisible = ref(false);
    var previewImage = ref('');
    var selected = useVModel(props, 'value', emit);

    var handlePreview = /*#__PURE__*/function () {
      var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(file) {
        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                if (file.url) {
                  previewImage.value = file.url;
                  previewVisible.value = true;
                }

              case 1:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      }));

      return function handlePreview(_x) {
        return _ref2.apply(this, arguments);
      };
    }();

    var beforeUploadFun = function beforeUploadFun(file) {
      var index = file.name.lastIndexOf('.');
      var filename = new Date().getTime() + '.' + file.name.substring(index + 1, file.name.length);
      uploaddata.value.key = 'uploads/' + filename;
      uploaddata.value.name = filename;
    };

    var handleChange = function handleChange(v) {
      var _a;

      console.log(v);

      if (v.event) {
        if (v.event.percent == 100) {
          (_a = selected.value) === null || _a === void 0 ? void 0 : _a.push({
            uid: new Date().getTime(),
            url: uploaddata.value.host + '/' + uploaddata.value.key,
            name: uploaddata.value.name
          });
          console.log(selected.value);
        }
      }
    };

    var heanleRemove = function heanleRemove(file) {
      var _a;

      (_a = selected.value) === null || _a === void 0 ? void 0 : _a.forEach(function (res, index) {
        var _a;

        if (res.uid == file.uid) {
          (_a = selected.value) === null || _a === void 0 ? void 0 : _a.splice(index, 1);
        }
      });
    };

    watchEffect(function () {
      uploaddata.value = props.data;
    });
    return function () {
      return _createVNode(_Fragment, null, [_createVNode("div", {
        "class": "upload_cont"
      }, [_createVNode(_resolveComponent("a-upload"), {
        "action": props.action,
        "data": uploaddata.value,
        "file-list": selected.value,
        "list-type": "picture-card",
        "beforeUpload": beforeUploadFun,
        "onPreview": handlePreview,
        "onChange": handleChange,
        "remove": heanleRemove
      }, {
        "default": function _default() {
          return [selected.value.length < props.size ? _createVNode("div", {
            "style": "font-size:30px;"
          }, [_createTextVNode("+")]) : ''];
        }
      })]), _createVNode(_resolveComponent("a-modal"), {
        "visible": previewVisible.value,
        "footer": "",
        "onCancel": function onCancel() {
          previewVisible.value = false;
        }
      }, {
        "default": function _default() {
          return [_createVNode("img", {
            "alt": "example",
            "style": "width: 100%",
            "src": previewImage.value
          }, null)];
        }
      })]);
    };
  }
});

==> pulin-vue3-common-0.0.21.tgz: package/es/components/MyUpload/index.js <==
import { resolveComponent as _resolveComponent, createVNode as _createVNode, createTextVNode as _createTextVNode, Fragment as _Fragment } from "vue";

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

import { defineComponent, ref, watchEffect } from 'vue';
import { useVModel } from '@vueuse/core';
export var MyUpload = defineComponent({
  props: {
    value: Array,
    action: String,
    data: Object,
    size: {
      type: Number,
      "default": 5
    }
  },
  setup: function setup(props, _ref) {
    var emit = _ref.emit;
    var uploaddata = ref({});
    var previewVisible = ref(false);
    var previewImage = ref('');
    var selected = useVModel(props, 'value', emit);

    var handlePreview = /*#__PURE__*/function () {
      var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(file) {
        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                if (file.url) {
                  previewImage.value = file.url;
                  previewVisible.value = true;
                }

              case 1:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      }));

      return function handlePreview(_x) {
        return _ref2.apply(this, arguments);
      };
    }();

    var beforeUploadFun = function beforeUploadFun(file) {
      var index = file.name.lastIndexOf('.');
      var filename = new Date().getTime() + '.' + file.name.substring(index + 1, file.name.length);
      uploaddata.value.key = 'uploads/' + filename;
      uploaddata.value.name = filename;
    };

    var handleChange = function handleChange(v) {
      var _a;

      console.log(v, v.event, '上传');
      (_a = selected.value) === null || _a === void 0 ? void 0 : _a.push({
        uid: new Date().getTime(),
        url: uploaddata.value.host + '/' + uploaddata.value.key,
        name: uploaddata.value.name
      }); // if (v.event) {
      //   if (v.event.percent == 100) {
      //     selected.value?.push({
      //       uid: new Date().getTime(),
      //       url: uploaddata.value.host + '/' + uploaddata.value.key,
      //       name: uploaddata.value.name,
      //     });
      //     console.log(selected.value);
      //   }
      // }
    };

    var heanleRemove = function heanleRemove(file) {
      var _a;

      (_a = selected.value) === null || _a === void 0 ? void 0 : _a.forEach(function (res, index) {
        var _a;

        if (res.uid == file.uid) {
          (_a = selected.value) === null || _a === void 0 ? void 0 : _a.splice(index, 1);
        }
      });
    };

    watchEffect(function () {
      uploaddata.value = props.data;
    });
    return function () {
      return _createVNode(_Fragment, null, [_createVNode("div", {
        "class": "upload_cont"
      }, [_createVNode(_resolveComponent("a-upload"), {
        "action": props.action,
        "data": uploaddata.value,
        "file-list": selected.value,
        "list-type": "picture-card",
        "beforeUpload": beforeUploadFun,
        "onPreview": handlePreview,
        "onChange": handleChange,
        "remove": heanleRemove
      }, {
        "default": function _default() {
          return [selected.value.length < props.size ? _createVNode("div", {
            "style": "font-size:30px;"
          }, [_createTextVNode("+")]) : ''];
        }
      })]), _createVNode(_resolveComponent("a-modal"), {
        "visible": previewVisible.value,
        "footer": "",
        "onCancel": function onCancel() {
          previewVisible.value = false;
        }
      }, {
        "default": function _default() {
          return [_createVNode("img", {
            "alt": "example",
            "style": "width: 100%",
            "src": previewImage.value
          }, null)];
        }
      })]);
    };
  }
});
